# auth — features


本 domain 下的所有功能：

- ✅ [FEAT-001 register](./FEAT-001-register.md) — done
- ✅ [FEAT-002 verify](./FEAT-002-verify.md) — done
- ✅ [FEAT-003 logout](./FEAT-003-logout.md) — done
- ✅ [FEAT-004 me](./FEAT-004-me.md) — done
